@@ -526,7 +526,7 @@ GtkWidget * ascp_draw_base(gfloat min, gfloat max)
 static void parse_base(gfloat min, gfloat max)
 {
 	gfloat incr;
-	gchar *buffer = (gchar*) g_malloc0(1024);
+	gchar *buffer = (gchar*) g_malloc0(BUFFERSIZE);
 	FILE *backupfile;
 
 	BaseFile =  g_malloc(16);
@@ -540,7 +540,7 @@ static void parse_base(gfloat min, gfloat max)
 
 	ascp_update_status(NULL, "base", min);
 
-	while (fgets(buffer, 1024, IoFile) != NULL)
+	while (fgets(buffer, BUFFERSIZE, IoFile) != NULL)
 	{
 		char* line = buffer;
 
