@@ -473,6 +473,7 @@ gint style_item_selected(GtkWidget   *clist, gint row, gint column,
 			gtk_container_add(GTK_CONTAINER(StyleEntryIcon), gtk_label_new("\nNone\n"));
 		}
 
+		gtk_widget_draw_default(StyleEntryIcon);
 		gtk_widget_show_all(StyleEntryIcon);
 
 
@@ -535,7 +536,7 @@ void property_button_callback (GtkWidget *widget, gpointer data)
 
 static void parse_database(gfloat min, gfloat max)
 {
-	gchar *buffer = (gchar*) g_malloc0(1024);
+	gchar *buffer = (gchar*) g_malloc0(BUFFERSIZE);
 	gfloat incr = (max - min)/FILESIZE;
 	gint number=0;
 	FILE *backupfile;
@@ -549,7 +550,7 @@ static void parse_database(gfloat min, gfloat max)
 
 	if(1 || FILESIZE > 1)
 	{
-		while (fgets(buffer, 1024, IoFile) != NULL)
+		while (fgets(buffer, BUFFERSIZE, IoFile) != NULL)
 		{
 			char* line = buffer;
 
@@ -950,9 +951,11 @@ static void affect_style_entry_button(GtkWidget *widget, gint dowhat)
 		strcpy(CurrentIcon, "-");
 		
 		if(GTK_BIN(StyleEntryIcon)->child)
-			gtk_container_remove(GTK_CONTAINER(StyleEntryIcon),GTK_BIN(StyleEntryIcon)->child);
+			gtk_container_remove(GTK_CONTAINER(StyleEntryIcon),
+					GTK_BIN(StyleEntryIcon)->child);
 		
 		gtk_container_add(GTK_CONTAINER(StyleEntryIcon), gtk_label_new("\nNone\n"));
+		gtk_widget_draw_default(StyleEntryIcon);
 		gtk_widget_show_all(StyleEntryIcon);
 	}
 }
