@@ -995,7 +995,7 @@ GtkWidget * ascp_draw_pager(gfloat min, gfloat max)
 static void parse_pager(gfloat min, gfloat max)
 {
 
-	gchar *buffer = (gchar*) g_malloc0(1024);
+	gchar *buffer = (gchar*) g_malloc0(BUFFERSIZE);
 	gfloat incr;
 	gint wxyz;
 	FILE *backupfile;
@@ -1008,7 +1008,7 @@ static void parse_pager(gfloat min, gfloat max)
 
 	ascp_update_status(NULL, "pager", min); 
 
-	while (fgets(buffer, 1024, IoFile) != NULL)
+	while (fgets(buffer, BUFFERSIZE, IoFile) != NULL)
 	{
 		gchar *line = buffer;
 		/*      
@@ -1129,7 +1129,7 @@ static void parse_pager(gfloat min, gfloat max)
 			else if( !ascp_strncasecmp(line + 6, "DesktopImage", 12) )
 			{
 				int desk;
-				gchar infile[1024];
+				gchar infile[BUFFERSIZE];
 				char *s;
 				s = line + 18;
 			
