@@ -1216,7 +1216,7 @@ static void parse_wharf(gfloat min, gfloat max)
 {
 
 	gfloat incr;
-	gchar *buffer = (gchar*) g_malloc0(1024);
+	gchar *buffer = (gchar*) g_malloc0(BUFFERSIZE);
 	FILE *backupfile;
 
 #ifndef GTK_STABLE_VERSION 
@@ -1250,7 +1250,7 @@ static void parse_wharf(gfloat min, gfloat max)
 	parent[NestLevel] = NULL;
 #endif //  GTK_LIB_DEP_CODE
 
-	while (fgets(buffer, 1024, IoFile) != NULL)
+	while (fgets(buffer, BUFFERSIZE, IoFile) != NULL)
 	{
 		 char* line = buffer;
 
@@ -1316,6 +1316,7 @@ static void parse_wharf(gfloat min, gfloat max)
 				gtk_container_add(GTK_CONTAINER(WharfStyleIcon),
 					ascp_make_pixmap(WharfStyleIconName, SINGLE));
 
+				gtk_widget_draw_default(WharfStyleIcon);
 				gtk_widget_show_all(WharfStyleIcon);
 
 
@@ -1748,7 +1749,6 @@ GdkEventButton *event, gpointer data)
 	entry = (wharfentry *)  gtk_clist_get_row_data (GTK_CLIST (cwidget), CurrentRow); 
 
 
-	/* Avoid nasty crashes! */
 	if(entry)
 	{
 		if(entry->name)
@@ -1768,6 +1768,7 @@ GdkEventButton *event, gpointer data)
 				ascp_make_pixmap(entry->icon, SINGLE));
 
 		
+			gtk_widget_draw_default(WharfEntryIcon);
 			gtk_widget_show_all(WharfEntryIcon);
 		
 			if(entry->dots)
@@ -2308,6 +2309,7 @@ static void affect_wharf_entry_button(GtkWidget *widget, gint dowhat)
 
 
 		gtk_container_add(GTK_CONTAINER(WharfEntryIcon), gtk_label_new("\nNone\n"));
+		gtk_widget_draw_default(WharfEntryIcon);
 		gtk_widget_show_all(WharfEntryIcon);
 
 	}
@@ -2332,6 +2334,7 @@ static void affect_wharf_style_button(GtkWidget *widget, gint dowhat)
 		gtk_container_remove(GTK_CONTAINER(WharfStyleIcon),GTK_BIN(WharfStyleIcon)->child);
 
 	gtk_container_add(GTK_CONTAINER(WharfStyleIcon), gtk_label_new("\nNone\n"));
+	gtk_widget_draw_default(WharfStyleIcon);
 	gtk_widget_show_all(WharfStyleIcon);
 }
 						  
